/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/aurora-osx64-xr/build/xpcom/system/nsIAccelerometer.idl
 */

#ifndef __gen_nsIAccelerometer_h__
#define __gen_nsIAccelerometer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindow; /* forward declaration */


/* starting interface:    nsIAcceleration */
#define NS_IACCELERATION_IID_STR "0ec7ed95-dc9e-4d20-a5e2-8fc6a03bce67"

#define NS_IACCELERATION_IID \
  {0x0ec7ed95, 0xdc9e, 0x4d20, \
    { 0xa5, 0xe2, 0x8f, 0xc6, 0xa0, 0x3b, 0xce, 0x67 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIAcceleration : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IACCELERATION_IID)

  /* readonly attribute double alpha; */
  NS_SCRIPTABLE NS_IMETHOD GetAlpha(double *aAlpha) = 0;

  /* readonly attribute double beta; */
  NS_SCRIPTABLE NS_IMETHOD GetBeta(double *aBeta) = 0;

  /* readonly attribute double gamma; */
  NS_SCRIPTABLE NS_IMETHOD GetGamma(double *aGamma) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAcceleration, NS_IACCELERATION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIACCELERATION \
  NS_SCRIPTABLE NS_IMETHOD GetAlpha(double *aAlpha); \
  NS_SCRIPTABLE NS_IMETHOD GetBeta(double *aBeta); \
  NS_SCRIPTABLE NS_IMETHOD GetGamma(double *aGamma); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIACCELERATION(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetAlpha(double *aAlpha) { return _to GetAlpha(aAlpha); } \
  NS_SCRIPTABLE NS_IMETHOD GetBeta(double *aBeta) { return _to GetBeta(aBeta); } \
  NS_SCRIPTABLE NS_IMETHOD GetGamma(double *aGamma) { return _to GetGamma(aGamma); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIACCELERATION(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetAlpha(double *aAlpha) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAlpha(aAlpha); } \
  NS_SCRIPTABLE NS_IMETHOD GetBeta(double *aBeta) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBeta(aBeta); } \
  NS_SCRIPTABLE NS_IMETHOD GetGamma(double *aGamma) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetGamma(aGamma); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAcceleration : public nsIAcceleration
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIACCELERATION

  nsAcceleration();

private:
  ~nsAcceleration();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAcceleration, nsIAcceleration)

nsAcceleration::nsAcceleration()
{
  /* member initializers and constructor code */
}

nsAcceleration::~nsAcceleration()
{
  /* destructor code */
}

/* readonly attribute double alpha; */
NS_IMETHODIMP nsAcceleration::GetAlpha(double *aAlpha)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute double beta; */
NS_IMETHODIMP nsAcceleration::GetBeta(double *aBeta)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute double gamma; */
NS_IMETHODIMP nsAcceleration::GetGamma(double *aGamma)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIAccelerationListener */
#define NS_IACCELERATIONLISTENER_IID_STR "3386bed8-7393-4704-8ffc-1eb2c35432ff"

#define NS_IACCELERATIONLISTENER_IID \
  {0x3386bed8, 0x7393, 0x4704, \
    { 0x8f, 0xfc, 0x1e, 0xb2, 0xc3, 0x54, 0x32, 0xff }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIAccelerationListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IACCELERATIONLISTENER_IID)

  /* void onAccelerationChange (in nsIAcceleration aAcceleration); */
  NS_SCRIPTABLE NS_IMETHOD OnAccelerationChange(nsIAcceleration *aAcceleration) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAccelerationListener, NS_IACCELERATIONLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIACCELERATIONLISTENER \
  NS_SCRIPTABLE NS_IMETHOD OnAccelerationChange(nsIAcceleration *aAcceleration); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIACCELERATIONLISTENER(_to) \
  NS_SCRIPTABLE NS_IMETHOD OnAccelerationChange(nsIAcceleration *aAcceleration) { return _to OnAccelerationChange(aAcceleration); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIACCELERATIONLISTENER(_to) \
  NS_SCRIPTABLE NS_IMETHOD OnAccelerationChange(nsIAcceleration *aAcceleration) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnAccelerationChange(aAcceleration); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAccelerationListener : public nsIAccelerationListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIACCELERATIONLISTENER

  nsAccelerationListener();

private:
  ~nsAccelerationListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAccelerationListener, nsIAccelerationListener)

nsAccelerationListener::nsAccelerationListener()
{
  /* member initializers and constructor code */
}

nsAccelerationListener::~nsAccelerationListener()
{
  /* destructor code */
}

/* void onAccelerationChange (in nsIAcceleration aAcceleration); */
NS_IMETHODIMP nsAccelerationListener::OnAccelerationChange(nsIAcceleration *aAcceleration)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIAccelerometer */
#define NS_IACCELEROMETER_IID_STR "4b04e228-0b33-43fc-971f-af60cedb1c21"

#define NS_IACCELEROMETER_IID \
  {0x4b04e228, 0x0b33, 0x43fc, \
    { 0x97, 0x1f, 0xaf, 0x60, 0xce, 0xdb, 0x1c, 0x21 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIAccelerometer : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IACCELEROMETER_IID)

  /* void addListener (in nsIAccelerationListener aListener); */
  NS_SCRIPTABLE NS_IMETHOD AddListener(nsIAccelerationListener *aListener) = 0;

  /* void removeListener (in nsIAccelerationListener aListener); */
  NS_SCRIPTABLE NS_IMETHOD RemoveListener(nsIAccelerationListener *aListener) = 0;

  /* void addWindowListener (in nsIDOMWindow aWindow); */
  NS_SCRIPTABLE NS_IMETHOD AddWindowListener(nsIDOMWindow *aWindow) = 0;

  /* void removeWindowListener (in nsIDOMWindow aWindow); */
  NS_SCRIPTABLE NS_IMETHOD RemoveWindowListener(nsIDOMWindow *aWindow) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAccelerometer, NS_IACCELEROMETER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIACCELEROMETER \
  NS_SCRIPTABLE NS_IMETHOD AddListener(nsIAccelerationListener *aListener); \
  NS_SCRIPTABLE NS_IMETHOD RemoveListener(nsIAccelerationListener *aListener); \
  NS_SCRIPTABLE NS_IMETHOD AddWindowListener(nsIDOMWindow *aWindow); \
  NS_SCRIPTABLE NS_IMETHOD RemoveWindowListener(nsIDOMWindow *aWindow); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIACCELEROMETER(_to) \
  NS_SCRIPTABLE NS_IMETHOD AddListener(nsIAccelerationListener *aListener) { return _to AddListener(aListener); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveListener(nsIAccelerationListener *aListener) { return _to RemoveListener(aListener); } \
  NS_SCRIPTABLE NS_IMETHOD AddWindowListener(nsIDOMWindow *aWindow) { return _to AddWindowListener(aWindow); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveWindowListener(nsIDOMWindow *aWindow) { return _to RemoveWindowListener(aWindow); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIACCELEROMETER(_to) \
  NS_SCRIPTABLE NS_IMETHOD AddListener(nsIAccelerationListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddListener(aListener); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveListener(nsIAccelerationListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveListener(aListener); } \
  NS_SCRIPTABLE NS_IMETHOD AddWindowListener(nsIDOMWindow *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddWindowListener(aWindow); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveWindowListener(nsIDOMWindow *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveWindowListener(aWindow); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAccelerometer : public nsIAccelerometer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIACCELEROMETER

  nsAccelerometer();

private:
  ~nsAccelerometer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAccelerometer, nsIAccelerometer)

nsAccelerometer::nsAccelerometer()
{
  /* member initializers and constructor code */
}

nsAccelerometer::~nsAccelerometer()
{
  /* destructor code */
}

/* void addListener (in nsIAccelerationListener aListener); */
NS_IMETHODIMP nsAccelerometer::AddListener(nsIAccelerationListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeListener (in nsIAccelerationListener aListener); */
NS_IMETHODIMP nsAccelerometer::RemoveListener(nsIAccelerationListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addWindowListener (in nsIDOMWindow aWindow); */
NS_IMETHODIMP nsAccelerometer::AddWindowListener(nsIDOMWindow *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeWindowListener (in nsIDOMWindow aWindow); */
NS_IMETHODIMP nsAccelerometer::RemoveWindowListener(nsIDOMWindow *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIAccelerometerUpdate */
#define NS_IACCELEROMETERUPDATE_IID_STR "22dd1d8a-51bf-406f-8b6d-d1919f8f1c7d"

#define NS_IACCELEROMETERUPDATE_IID \
  {0x22dd1d8a, 0x51bf, 0x406f, \
    { 0x8b, 0x6d, 0xd1, 0x91, 0x9f, 0x8f, 0x1c, 0x7d }}

class NS_NO_VTABLE nsIAccelerometerUpdate : public nsIAccelerometer {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IACCELEROMETERUPDATE_IID)

  /* void accelerationChanged (in double alpha, in double beta, in double gamma); */
  NS_IMETHOD AccelerationChanged(double alpha, double beta, double gamma) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAccelerometerUpdate, NS_IACCELEROMETERUPDATE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIACCELEROMETERUPDATE \
  NS_IMETHOD AccelerationChanged(double alpha, double beta, double gamma); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIACCELEROMETERUPDATE(_to) \
  NS_IMETHOD AccelerationChanged(double alpha, double beta, double gamma) { return _to AccelerationChanged(alpha, beta, gamma); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIACCELEROMETERUPDATE(_to) \
  NS_IMETHOD AccelerationChanged(double alpha, double beta, double gamma) { return !_to ? NS_ERROR_NULL_POINTER : _to->AccelerationChanged(alpha, beta, gamma); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAccelerometerUpdate : public nsIAccelerometerUpdate
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIACCELEROMETERUPDATE

  nsAccelerometerUpdate();

private:
  ~nsAccelerometerUpdate();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAccelerometerUpdate, nsIAccelerometerUpdate)

nsAccelerometerUpdate::nsAccelerometerUpdate()
{
  /* member initializers and constructor code */
}

nsAccelerometerUpdate::~nsAccelerometerUpdate()
{
  /* destructor code */
}

/* void accelerationChanged (in double alpha, in double beta, in double gamma); */
NS_IMETHODIMP nsAccelerometerUpdate::AccelerationChanged(double alpha, double beta, double gamma)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAccelerometer_h__ */
