/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is DevTools code
 *
 * The Initial Developer of the Original Code is
 *   Mozilla Corporation
 * Portions created by the Initial Developer are Copyright (C) 2010
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Joe Walker <jwalker@mozilla.com>
 *   Julian Viereck <jviereck@mozilla.com>
 *   Mihai Șucan <mihai.sucan@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

body {
  font-family: sans-serif;
  font-size: 11px;
  background: #EEE;
  color: #000;
}

#header {
  padding: 5px;
  overflow-x:auto;
  display: block;
}

h1 {
  font-size: 13px;
  line-height: 15px;
  padding: 3px 10px;
  vertical-align: bottom;
  margin: 0px;
  background: -moz-linear-gradient(top, #BBB, #999);
  border-radius: 2px;
  text-shadow: #FFF 0px 1px 0px;
}

h1 .info {
  font-size: 11px;
  line-height: 15px;
  vertical-align: bottom;
  float: right;
  color: #333;
  padding-right: 3px;
}

.property-table {
  padding: 2px 5px;
  background: -moz-linear-gradient(top, #FFF, #F8F8F8);
  color: #333;
  width: 100%;
  max-height: 330px;
  overflow: auto;
  display: block;
}

.property-name {
  font-size: 11px;
  font-weight: bold;
  padding-right: 4px;
  color: #000;
  white-space: nowrap;
  text-align: right;
  vertical-align: top;
  width: 10%;
}

.property-value {
  padding-right: 5px;
  font-size: 11px;
  word-wrap: break-word;
  width: 90%;
}

div.group {
  margin-top: 10px;
}

div.group,
#header {
  background: #FFF;
  border-color: #E1E1E1;
  border-style: solid;
  border-width: 1px;
  box-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.2);
  border-radius: 4px 4px 4px 4px;
}

img#responseImageNode {
  box-shadow: rgba(0,0,0,0.2) 0px 3px 3.5px;
  max-width: 100%;
}

#responseImageNodeDiv {
  padding: 5px;
}
